/* crlfetch.h - LDAP access
 *      Copyright (C) 2002 Klarlvdalens Datakonsult AB
 *
 * This file is part of DirMngr.
 *
 * DirMngr is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * DirMngr is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 */

#ifndef CRLFETCH_H
#define CRLFETCH_H

#include "../jnlib/types.h"
#include "../jnlib/strlist.h"
#include "dirmngr.h"

/* Normally, the return codes are the ASSUAN_* macros, but we need 
   one addition code to tell when the output has been truncated
*/
#define ASSUAN_DIRMNGR_Result_Truncated 4711

/* Fetch CRL from url, returns ASSUAN_No_Error on success */
int crl_fetch( const char* url, char** value, size_t* valuelen );
/* Fetch CRL for issuer using default server, 
   returns ASSUAN_No_Error on success */
int crl_fetch_default( const char* issuer, char** value, size_t* valuelen );
/* Fetch cert for dn, returns ASSUAN_No_Error on success */
int ca_cert_fetch( const char* dn, char** value, size_t* valuelen );


/* Query the server for certs matching patterns */
int start_cert_fetch( STRLIST patterns, const struct ldap_server_s *server );
int fetch_next_cert( char** value, size_t* valuelen );
int end_cert_fetch(void);

/* from ldap.c */
int attr_fetch_ldap( const char* dn, const char* attr, char** value, size_t* valuelen );
int url_fetch_ldap(const char* url, const char* attr, char** value, size_t* valuelen );

int start_cert_fetch_ldap( STRLIST patterns, const struct ldap_server_s *server );
int fetch_next_cert_ldap( char** value, size_t* valuelen );
int end_cert_fetch_ldap(void);


#endif /* CRLFETCH_H */
